https://issues.apache.org/jira/browse/AMQNET-468
diff --git a/src/main/csharp/Transport/Tcp/SslTransport.cs b/src/main/csharp/Transport/Tcp/SslTransport.cs
index 736a643..64924e4 100644
--- a/src/main/csharp/Transport/Tcp/SslTransport.cs
+++ b/src/main/csharp/Transport/Tcp/SslTransport.cs
@@ -173,7 +173,7 @@
                 Tracer.Error("The Remote Certificate was not Available.");
             }
 
             // Configuration may or may not allow us to connect with an invliad broker cert.
             return AcceptInvalidBrokerCert;
         }
 
@@ -237,7 +237,7 @@
                     }
                     else
                     {
-                        throw new NMSException("Invlalid StoreLocation given on URI");
+                        throw new NMSException("Invalid StoreLocation given on URI");
                     }
                 }
@@ -173,7 +173,7 @@
             }
 
-            // Configuration may or may not allow us to connect with an invliad broker cert.
+            // Configuration may or may not allow us to connect with an invalid broker cert.
             return AcceptInvalidBrokerCert;
         }